@@ -10,11 +10,11 @@ ActiveRecord::Simple - Simple to use lightweight implementation of ActiveRecord
 
 =head1 VERSION
 
-Version 0.61.0
+Version 0.62
 
 =cut
 
-our $VERSION = '0.61';
+our $VERSION = '0.62';
 
 use utf8;
 use Encode;
@@ -281,6 +281,9 @@ sub has_many {
 sub as_sql {
     my ($class, $producer_name, %args) = @_;
 
+    $class->can('_get_schema_table')
+        or return;
+
     my $t = SQL::Translator->new;
     my $schema = $t->schema;
     $schema->add_table($class->_get_schema_table);
@@ -1023,7 +1026,7 @@ ActiveRecord::Simple
 
 =head1 VERSION
 
-0.60.1
+0.61.1
 
 =head1 DESCRIPTION
 
@@ -1144,12 +1147,6 @@ about available data types.
 Set name of the primary key. This method is not required to use in the child
 (your model) classes.
 
-=head2 index
-
-    __PACKAGE__->index('index_id_person', ['id_person']);
-
-Create an index and add it to the schema. Works only when method "fields" is using.
-
 =head2 table_name
 
     __PACKAGE__->table_name('persons');
